Chromium Code Reviews

Unified Diff: sdk/lib/_internal/pub/test/global/activate/outdated_binstub_test.dart

Issue 899373002: Update pub to use the VM's new bad-snapshot exit code. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Fix status and one more test Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Index: sdk/lib/_internal/pub/test/global/activate/outdated_binstub_test.dart
diff --git a/sdk/lib/_internal/pub/test/global/activate/outdated_binstub_test.dart b/sdk/lib/_internal/pub/test/global/activate/outdated_binstub_test.dart
index 51bcc837bab0a730a4f8c0f2c39c29d3ee454e19..51780ceb71c2111cfc890a27d47cba42bb2137d7 100644
--- a/sdk/lib/_internal/pub/test/global/activate/outdated_binstub_test.dart
+++ b/sdk/lib/_internal/pub/test/global/activate/outdated_binstub_test.dart
@@ -50,8 +50,8 @@ main() {
d.dir(cachePath, [
d.dir('bin', [
- // 255 is the VM's exit code upon seeing an out-of-date snapshot.
- d.matcherFile(binStubName('foo-script'), contains("255"))
+ // 253 is the VM's exit code upon seeing an out-of-date snapshot.
+ d.matcherFile(binStubName('foo-script'), contains("253"))
])
]).validate();
});

Powered by Google App Engine